"use client"

import { useState } from 'react';
import { motion } from 'framer-motion';
import { Ship, Package, MapPin, ArrowRight } from 'lucide-react';
import { Button } from '@/components/ui/button';

export default function Home() {
  const [isHovered, setIsHovered] = useState(false);

  return (
    <div className="min-h-screen bg-gradient-to-b from-background to-background/95">
      <nav className="fixed w-full z-50 glass-card">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex items-center justify-between h-16">
            <div className="flex items-center">
              <Ship className="h-8 w-8 text-primary" />
              <span className="ml-2 text-xl font-bold neon-glow">Conde Express</span>
            </div>
            <div className="hidden md:block">
              <div className="ml-10 flex items-baseline space-x-4">
                <Button variant="ghost">Services</Button>
                <Button variant="ghost">Track Shipment</Button>
                <Button variant="ghost">About Us</Button>
                <Button variant="ghost">Contact</Button>
                <Button>Login</Button>
              </div>
            </div>
          </div>
        </div>
      </nav>

      <main className="pt-16">
        <section className="relative h-screen flex items-center">
          <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
            <div className="lg:grid lg:grid-cols-12 lg:gap-8">
              <div className="col-span-6 space-y-8">
                <motion.h1 
                  className="text-5xl font-bold leading-tight neon-glow"
                  initial={{ opacity: 0, y: 20 }}
                  animate={{ opacity: 1, y: 0 }}
                  transition={{ duration: 0.5 }}
                >
                  Maritime Shipping
                  <br />
                  <span className="text-primary">Redefined</span>
                </motion.h1>
                <motion.p 
                  className="text-xl text-muted-foreground"
                  initial={{ opacity: 0, y: 20 }}
                  animate={{ opacity: 1, y: 0 }}
                  transition={{ duration: 0.5, delay: 0.2 }}
                >
                  Door-to-door shipping services from New York to Dominican Republic.
                  Fast, secure, and reliable maritime logistics solutions.
                </motion.p>
                <motion.div
                  className="flex gap-4"
                  initial={{ opacity: 0, y: 20 }}
                  animate={{ opacity: 1, y: 0 }}
                  transition={{ duration: 0.5, delay: 0.4 }}
                >
                  <Button size="lg" className="hover-glow">
                    Get Started
                    <ArrowRight className="ml-2 h-4 w-4" />
                  </Button>
                  <Button size="lg" variant="outline">
                    Track Shipment
                  </Button>
                </motion.div>
              </div>
              <div className="col-span-6 mt-8 lg:mt-0">
                <div className="grid grid-cols-2 gap-4">
                  {[
                    { icon: Ship, title: "Maritime Expertise", desc: "Professional shipping services" },
                    { icon: Package, title: "Door to Door", desc: "Complete logistics solution" },
                    { icon: MapPin, title: "Real-time Tracking", desc: "Monitor your shipments 24/7" },
                  ].map((feature, index) => (
                    <motion.div
                      key={index}
                      className="glass-card p-6 rounded-2xl hover-glow cursor-pointer"
                      initial={{ opacity: 0, y: 20 }}
                      animate={{ opacity: 1, y: 0 }}
                      transition={{ duration: 0.5, delay: 0.2 * (index + 3) }}
                      whileHover={{ scale: 1.05 }}
                    >
                      <feature.icon className="h-8 w-8 text-primary mb-4" />
                      <h3 className="text-lg font-semibold mb-2">{feature.title}</h3>
                      <p className="text-sm text-muted-foreground">{feature.desc}</p>
                    </motion.div>
                  ))}
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </div>
  );
}